@@ -61,7 +61,7 @@ Net::XMPP::IQ - XMPP Info/Query Module
 
     use Net::XMPP;
 
-    $IQ = Net::XMPP::IQ->new();
+    $IQ = new Net::XMPP::IQ();
     $IQType = $IQ->NewChild( type );
     $IQType->SetXXXXX("yyyyy");
 
@@ -256,16 +256,12 @@ Net::XMPP::IQ - XMPP Info/Query Module
 
 =head1 AUTHOR
 
-Originally authored by Ryan Eatmon.
-
-Previously maintained by Eric Hacker. 
-
-Currently maintained by Darian Anthony Patrick.
+Ryan Eatmon
 
 =head1 COPYRIGHT
 
 This module is free software, you can redistribute it and/or modify it
-under the LGPL 2.1.
+under the LGPL.
 
 =cut
 
@@ -294,7 +290,7 @@ sub new
     return $self;
 }
 
-sub _iq { my $self = shift; return Net::XMPP::IQ->new(); }
+sub _iq { my $self = shift; return new Net::XMPP::IQ(); }
 
 $FUNCTIONS{Error}->{path} = 'error/text()';
 
