@@ -54,7 +54,7 @@ Net::XMPP::Message - XMPP Message Module
 
     use Net::XMPP;
 
-    $Mess = Net::XMPP::Message->new();
+    $Mess = new Net::XMPP::Message();
 
   Now you can call the creation functions below to populate the tag
   before sending it.
@@ -279,16 +279,12 @@ Net::XMPP::Message - XMPP Message Module
 
 =head1 AUTHOR
 
-Originally authored by Ryan Eatmon.
-
-Previously maintained by Eric Hacker. 
-
-Currently maintained by Darian Anthony Patrick.
+Ryan Eatmon
 
 =head1 COPYRIGHT
 
 This module is free software, you can redistribute it and/or modify it
-under the LGPL 2.1.
+under the LGPL.
 
 =cut
 
@@ -318,7 +314,7 @@ sub new
     return $self;
 }
 
-sub _message { my $self = shift; return Net::XMPP::Message->new(); }
+sub _message { my $self = shift; return new Net::XMPP::Message(); }
 
 # Copied from Net::Jabber::Message because GetTimeStamp doesn't work without DefinedX
 sub GetX     { my $self = shift; $self->GetChild(@_);    }
