@@ -27,7 +27,7 @@ Net::XMPP::PrivacyLists - XMPP Privacy Lists Object
 
 =head1 SYNOPSIS
 
-This module is not yet complete.  Do not use.
+  This module is not yet complete.  Do not use.
 
 =head1 DESCRIPTION
 
@@ -43,22 +43,17 @@ This module is not yet complete.  Do not use.
 
 =head1 AUTHOR
 
-Originally authored by Ryan Eatmon.
-
-Previously maintained by Eric Hacker. 
-
-Currently maintained by Darian Anthony Patrick.
+Ryan Eatmon
 
 =head1 COPYRIGHT
 
 This module is free software, you can redistribute it and/or modify it
-under the LGPL 2.1.
+under the LGPL.
 
 =cut
 
 use strict;
 use Carp;
-use XML::Stream;
 
 sub new
 {
